@@ -1,26 +1,24 @@
 /*
- Copyright  2002-2004 MySQL AB, 2008 Sun Microsystems
- All rights reserved. Use is subject to license terms.
+ Copyright (c) 2002, 2010, Oracle and/or its affiliates. All rights reserved.
+ 
 
-  The MySQL Connector/J is licensed under the terms of the GPL,
-  like most MySQL Connectors. There are special exceptions to the
-  terms and conditions of the GPL as it is applied to this software,
-  see the FLOSS License Exception available on mysql.com.
+  The MySQL Connector/J is licensed under the terms of the GPLv2
+  <http://www.gnu.org/licenses/old-licenses/gpl-2.0.html>, like most MySQL Connectors.
+  There are special exceptions to the terms and conditions of the GPLv2 as it is applied to
+  this software, see the FLOSS License Exception
+  <http://www.mysql.com/about/legal/licensing/foss-exception.html>.
 
-  This program is free software; you can redistribute it and/or
-  modify it under the terms of the GNU General Public License as
-  published by the Free Software Foundation; version 2 of the
-  License.
+  This program is free software; you can redistribute it and/or modify it under the terms
+  of the GNU General Public License as published by the Free Software Foundation; version 2
+  of the License.
 
-  This program is distributed in the hope that it will be useful,  
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-  GNU General Public License for more details.
+  This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
+  without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+  See the GNU General Public License for more details.
 
-  You should have received a copy of the GNU General Public License
-  along with this program; if not, write to the Free Software
-  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
-  02110-1301 USA
+  You should have received a copy of the GNU General Public License along with this
+  program; if not, write to the Free Software Foundation, Inc., 51 Franklin St, Fifth
+  Floor, Boston, MA 02110-1301  USA
 
 
 
@@ -63,8 +61,6 @@ public class SubqueriesRegressionTest extends BaseTestCase {
 	 * @see junit.framework.TestCase#tearDown()
 	 */
 	public void tearDown() throws Exception {
-		dropTables();
-		
 		super.tearDown();
 	}
 
@@ -87,17 +83,11 @@ public class SubqueriesRegressionTest extends BaseTestCase {
 		if (versionMeetsMinimum(4, 1)) {
 			for (int i = 0; i < REPETITIONS; i++) {
 
-				try {
 					this.rs = this.stmt
 							.executeQuery("select t3.colA from t3, t1 where t3.colA = 'bbbb' and t3.colB = t1.colA and exists (select 'X' from t2 where t2.colB = t1.colB)");
 					assertTrue(this.rs.next());
 					assertTrue("bbbb".equals(this.rs.getString(1)));
 					assertTrue(!this.rs.next());
-				} finally {
-					if (this.rs != null) {
-						this.rs.close();
-					}
-				}
 			}
 		}
 	}
@@ -111,17 +101,13 @@ public class SubqueriesRegressionTest extends BaseTestCase {
 	public void testSubQuery2() throws Exception {
 		if (versionMeetsMinimum(4, 1)) {
 			for (int i = 0; i < REPETITIONS; i++) {
-				try {
+
 					this.rs = this.stmt
 							.executeQuery("select t3.colA from t3, t1 where t3.colA = 'bbbb' and t3.colB = t1.colA and exists (select 'X' from t2 where t2.colB = 2)");
 					assertTrue(this.rs.next());
 					assertTrue("bbbb".equals(this.rs.getString(1)));
 					assertTrue(!this.rs.next());
-				} finally {
-					if (this.rs != null) {
-						this.rs.close();
-					}
-				}
+				
 			}
 		}
 	}
@@ -135,19 +121,14 @@ public class SubqueriesRegressionTest extends BaseTestCase {
 	public void testSubQuery3() throws Exception {
 		if (versionMeetsMinimum(4, 1)) {
 			for (int i = 0; i < REPETITIONS; i++) {
-				try {
+
 					this.rs = this.stmt
 							.executeQuery("select * from t1 where t1.colA = 'efgh' and exists (select 'X' from t2 where t2.colB = t1.colB)");
 					assertTrue(this.rs.next());
 					assertTrue("efgh".equals(this.rs.getString(1)));
 					assertTrue("2".equals(this.rs.getString(2)));
 					assertTrue(!this.rs.next());
-				} finally {
-					if (this.rs != null) {
-						this.rs.close();
-					}
 
-				}
 			}
 		}
 	}
@@ -162,7 +143,6 @@ public class SubqueriesRegressionTest extends BaseTestCase {
 		// not really a subquery, but we want to have this in our testsuite
 		if (versionMeetsMinimum(4, 1)) {
 			for (int i = 0; i < REPETITIONS; i++) {
-				try {
 					this.rs = this.stmt
 							.executeQuery("select colA, '' from t2 union select colA, colB from t3");
 
@@ -195,11 +175,6 @@ public class SubqueriesRegressionTest extends BaseTestCase {
 							.getString(2)));
 
 					assertTrue(!this.rs.next());
-				} finally {
-					if (this.rs != null) {
-						this.rs.close();
-					}
-				}
 			}
 		}
 	}
@@ -214,7 +189,6 @@ public class SubqueriesRegressionTest extends BaseTestCase {
 		if (versionMeetsMinimum(4, 1)) {
 			for (int i = 0; i < REPETITIONS; i++) {
 
-				try {
 					this.rs = this.stmt
 							.executeQuery("select t1.colA from t1, t4 where t4.colA = t1.colA and exists (select 'X' from t2 where t2.colA = t4.colB)");
 					assertTrue(this.rs.next());
@@ -224,29 +198,16 @@ public class SubqueriesRegressionTest extends BaseTestCase {
 					assertTrue(this.rs.next());
 					assertTrue("ijkl".equals(this.rs.getString(1)));
 					assertTrue(!this.rs.next());
-				} finally {
-					if (this.rs != null) {
-						this.rs.close();
-					}
-				}
+
 			}
 		}
 	}
 
 	private void createTables() throws Exception {
-		this.stmt.executeUpdate("drop table if exists t1");
-		this.stmt.executeUpdate("drop table if exists t1");
-		this.stmt.executeUpdate("drop table if exists t2");
-		this.stmt.executeUpdate("drop table if exists t3");
-		this.stmt.executeUpdate("drop table if exists t4");
-		this.stmt
-				.executeUpdate("create table t1(colA varchar(10), colB decimal(3,0))");
-		this.stmt
-				.executeUpdate("create table t2(colA varchar(10), colB varchar(10))");
-		this.stmt
-				.executeUpdate("create table t3(colA varchar(10), colB varchar(10))");
-		this.stmt
-				.executeUpdate("create table t4(colA varchar(10), colB varchar(10))");
+		createTable("t1", "(colA varchar(10), colB decimal(3,0))");
+		createTable("t2", "(colA varchar(10), colB varchar(10))");
+		createTable("t3", "(colA varchar(10), colB varchar(10))");
+		createTable("t4", "(colA varchar(10), colB varchar(10))");
 		this.stmt
 				.executeUpdate("insert into t1 values ('abcd', 1), ('efgh', 2), ('ijkl', 3)");
 		this.stmt
@@ -257,11 +218,4 @@ public class SubqueriesRegressionTest extends BaseTestCase {
 				.executeUpdate("insert into t4 values ('abcd', 'type1'), ('efgh', 'type2'), ('ijkl', 'type3')");
 	}
 
-	private void dropTables() throws Exception {
-		this.stmt.executeUpdate("drop table if exists t1");
-		this.stmt.executeUpdate("drop table if exists t1");
-		this.stmt.executeUpdate("drop table if exists t2");
-		this.stmt.executeUpdate("drop table if exists t3");
-		this.stmt.executeUpdate("drop table if exists t4");
-	}
 }
